@@ -1,11 +1,13 @@
 #' Plot event years for individual trees
 #'
-#' @description The function creates a dot plot showing positive and negative event year values from a \code{list} of the type as produced by \code{\link{pointer.norm}} or \code{\link{pointer.rgc}}.
+#' @description The function creates a dot plot showing positive and (or) negative event years from a \code{list} of the type as produced by \code{\link{pointer.norm}} or \code{\link{pointer.rgc}}.
 #' 
-#' @usage event.plot(list.name, start.yr = NULL, end.yr = NULL,
+#' @usage event.plot(list.name, sign = c("both", "pos", "neg"),
+#'            start.yr = NULL, end.yr = NULL,
 #'            x.tick.major = 10, x.tick.minor = 5) 
 #'
 #' @param list.name a \code{list} as produced by \code{\link{pointer.norm}} or \code{\link{pointer.rgc}}
+#' @param sign a \code{character} string specifying whether both positive and negative (\code{"both"}), or only positive (\code{"pos"}) or negative (\code{"neg"}) event years should be displayed. Defaults to \code{"both"}.
 #' @param start.yr an \code{integer} specifying the first year to be plotted. Defaults to the first year with data if \code{\var{start.yr}} is \code{NULL}.
 #' @param end.yr an \code{integer} specifying the last year to be plotted. Defaults to the last year with data if \code{\var{end.yr}} is \code{NULL}.
 #' @param x.tick.major an \code{integer} controlling the major x-axis tick labels. Defaults to 10 years.
@@ -13,26 +15,20 @@
 #' 
 #' @details The function makes a dot plot showing event years for individual trees. Positive and negative event years are indicated with different symbols. If event years were defined using \code{method.thresh "Neuwirth"} (\code{\link{pointer.norm}}), different tones of gray indicate weak, strong and extreme event years.
 #' 
-#' Non-event years are indicated with minus-signs, allowing the assessment of individual series length.
-#' 
 #' @return 
 #' Dot plot.
 #'
 #' @author Marieke van der Maaten-Theunissen and Ernst van der Maaten.
 #'
-#' @examples ## Plot event years for individual trees as generated using pointer.rgc
+#' @examples ## Plot event years from pointer.rgc output
 #' data(s033)
-#' py <- pointer.rgc(s033, nb.yrs = 4, rgc.thresh.pos = 60, rgc.thresh.neg = 40, 
-#'                   series.thresh = 75)
-#' event.plot(py, start.yr = 1950, end.yr = NULL,
-#'            x.tick.major = 10, x.tick.minor = 5) 
+#' py <- pointer.rgc(s033)
+#' event.plot(py, start.yr = 1950, end.yr = NULL) 
 #'
-#' ## Plot event years for individual trees as generated using pointer.norm (method "Neuwirth")
+#' ## Plot negative event years from pointer.norm output (method "Neuwirth")
 #' data(s033)
-#' py_n <- pointer.norm(s033, window = 5, method.thresh = "Neuwirth",
-#'                      series.thresh = 75)
-#' event.plot(py_n, start.yr = 1950, end.yr = NULL,
-#'            x.tick.major = 10, x.tick.minor = 5) 
+#' py_n <- pointer.norm(s033, window = 5, method.thresh = "Neuwirth")
+#' event.plot(py_n, sign = "neg", start.yr = 1950, end.yr = NULL) 
 #'            
 #' @import ggplot2
 #' @import stats
@@ -41,7 +37,7 @@
 #' 
 #' @export event.plot
 #' 
-event.plot <- function(list.name, start.yr = NULL, end.yr = NULL, x.tick.major = 10, x.tick.minor = 5) 
+event.plot <- function(list.name, sign = c("both", "pos", "neg"), start.yr = NULL, end.yr = NULL, x.tick.major = 10, x.tick.minor = 5) 
 {
   stopifnot(is.list(list.name))
   if(FALSE %in% (class(list.name)[1] == "pointer.rgc") & FALSE %in% (class(list.name)[1] == "pointer.norm")) {
@@ -60,14 +56,16 @@ event.plot <- function(list.name, start.yr = NULL, end.yr = NULL, x.tick.major =
     stop("'x.tick.minor' should be smaller then 'x.tick.major'")
   }
  
+  sign2 <- match.arg(sign, c("both", "pos", "neg"))
+  
   start.yr2 <- ifelse(length(start.yr) != 0, start.yr, min(list.name$out[, "year"]))
   end.yr2 <- ifelse(length(end.yr) != 0, end.yr, max(list.name$out[, "year"]))
   start.yr3 <- round_any(start.yr2, 10, f = floor)
   end.yr3 <- round_any(end.yr2, 5, f = ceiling)
   
   matrix <- list.name$EYvalues[as.character(start.yr2:end.yr2),]
-  input <- matrix2long(t(matrix), new.ids=FALSE)
-  input2 <- na.omit(input)
+  input <- matrix2long(t(matrix), new.ids = FALSE)
+  input2 <- na.omit(input) 
   rownames(input2) <- NULL
   colnames(input2) <-c ("tree","year","EYvalues")
   
@@ -76,9 +74,23 @@ event.plot <- function(list.name, start.yr = NULL, end.yr = NULL, x.tick.major =
   col.pos <- colnames(list.name$out)[3] == "perc.pos"
   
   if(col.pos) {
-    int.levels <- c(-1, 0, 1)
-    label.levels <- c("negative", "none", "positive")
-    shape.levels <- c(25, 95, 24)
+    if(sign2 == "both") {
+      int.levels <- c(-1, 0, 1)
+      label.levels <- c("negative", "none", "positive")
+      shape.levels <- c(25, 95, 24)
+    }
+    if(sign2 == "pos") {
+      input2[input2$EYvalues < 0, "EYvalues"] <- 0
+      int.levels <- c(0, 1)
+      label.levels <- c("other", "positive")
+      shape.levels <- c(95, 24)
+    }
+    if(sign2 == "neg") {
+      input2[input2$EYvalues > 0, "EYvalues"] <- 0
+      int.levels <- c(-1, 0)
+      label.levels <- c("negative", "other")
+      shape.levels <- c(25, 95)
+    }
     
     pl <- ggplot(input2, aes(x = year, y = tree, shape = factor(EYvalues))) 
     pl + geom_point(size = 2, colour = "black", fill = "#bdbdbd") +
@@ -90,11 +102,27 @@ event.plot <- function(list.name, start.yr = NULL, end.yr = NULL, x.tick.major =
                          limits = c(start.yr3, end.yr3))
   }
   else {
-    int.levels <- c(-3, -2, -1, 0, 1, 2, 3)
-    fill.levels <- c( "black", "#bdbdbd", "white" , "#bdbdbd", "white", "#bdbdbd", "black")
-    label.levels <- c("negative extreme", "negative strong", "negative weak",
+    if(sign2 == "both") {
+      int.levels <- c(-3, -2, -1, 0, 1, 2, 3)
+      fill.levels <- c("black", "#bdbdbd", "white" , "#bdbdbd", "white", "#bdbdbd", "black")
+      label.levels <- c("negative extreme", "negative strong", "negative weak",
                        "none", "positive weak", "positive strong", "positive extreme")
-    shape.levels <- c(25, 25, 25, 95, 24, 24, 24)
+      shape.levels <- c(25, 25, 25, 95, 24, 24, 24)
+    }
+    if(sign2 == "pos") {
+      input2[input2$EYvalues < 0, "EYvalues"] <- 0
+      int.levels <- c(0, 1, 2, 3)
+      fill.levels <- c("#bdbdbd", "white", "#bdbdbd", "black")
+      label.levels <- c("other", "positive weak", "positive strong", "positive extreme")
+      shape.levels <- c(95, 24, 24, 24)
+    }
+    if(sign2 == "neg") {
+      input2[input2$EYvalues > 0, "EYvalues"] <- 0
+      int.levels <- c(-3, -2, -1, 0)
+      fill.levels <- c("black", "#bdbdbd", "white" , "#bdbdbd")
+      label.levels <- c("negative extreme", "negative strong", "negative weak", "other")
+      shape.levels <- c(25, 25, 25, 95)
+    }
     
     pl <- ggplot(input2, aes(x = year, y = tree, shape = factor(EYvalues),
                              fill = factor(EYvalues))) 
@@ -108,10 +136,4 @@ event.plot <- function(list.name, start.yr = NULL, end.yr = NULL, x.tick.major =
                          minor_breaks = seq(start.yr3, end.yr3, x.tick.minor),
                          limits = c(start.yr3, end.yr3))
   }
-}
-
-
-
-
-
-
+}
\ No newline at end of file
